@@ -36,6 +36,7 @@ class TickLiveData:
 
     def __eq__(self, other):
         res = True
+        assert type(self) == type(other)
         try:
             if self.tick_seq != other.tick_seq:
                 res = False
@@ -91,6 +92,14 @@ class MinLiveData:
         # self.bids = []
         # self.asks = []
 
+    def __eq__(self, other):
+        res = True
+        assert type(self) == type(other)
+        if self.timestamp != other.timestamp\
+                or self.symbol != other.symbol:
+            res = False
+        return res
+
     def __str__(self):
         return str(self.__dict__)
 
